@@ -258,18 +258,7 @@ def quantify_mutex_exons(event, gene, counts_segments, counts_edges):
     return cov
 
 
-def quantify_from_counted_events(event_fn, strain_idx1=None, strain_idx2=None, event_type=None, options=None, out_fn=None, gen_event_ids=False, high_mem=False):
-
-    ### set parameters if called by rproc
-    if strain_idx1 is None:
-        PAR = event_fn
-        event_fn = PAR['event_fn']
-        strain_idx1 = PAR['strain_idx1']
-        strain_idx2 = PAR['strain_idx2']
-        if 'out_fn' in PAR:
-            out_fn = PAR['out_fn']
-        event_type = PAR['event_type']
-        options = PAR['options']
+def quantify_from_counted_events(event_fn, sample_idx1=None, sample_idx2=None, event_type=None, options=None, out_fn=None, gen_event_ids=False, high_mem=False):
 
     ### read count_data from event HDF5
     if high_mem:
@@ -283,7 +272,7 @@ def quantify_from_counted_events(event_fn, strain_idx1=None, strain_idx2=None, e
         event_idx = IN['filter_idx'][:].astype('int')
     else:
         event_idx = conf_idx.copy()
-    event_features = decodeUTF8(IN['event_features'][event_type][:])
+    event_features = decodeUTF8(IN['event_features'][:])
 
     ### arrays to collect exon coordinates for length normalization
     pos0e = []
@@ -291,25 +280,25 @@ def quantify_from_counted_events(event_fn, strain_idx1=None, strain_idx2=None, e
 
     ### get event features we need to include for counting
     if event_type == 'exon_skip':
-        fidx0i = [np.where(event_features == 'exon_pre_exon_aft_conf')[0]]
-        fidx1i = [np.where(event_features == 'exon_pre_exon_conf')[0], np.where(event_features == 'exon_exon_aft_conf')[0]] 
+        fidx0i = [np.where(event_features == 'e1e3_conf')[0]]
+        fidx1i = [np.where(event_features == 'e1e2_conf')[0], np.where(event_features == 'e2e3_conf')[0]] 
         if options.use_exon_counts:
             fidx0e = []
-            fidx1e = [np.where(event_features == 'exon_cov')[0]]
+            fidx1e = [np.where(event_features == 'e2_cov')[0]]
             pos1e = [IN['event_pos'][:, [2, 3]].astype('int')]
     elif event_type == 'intron_retention':
-        fidx0i = [np.where(event_features == 'intron_conf')[0]]
+        fidx0i = [np.where(event_features == 'e1e3_conf')[0]]
         fidx1i = []
         if options.use_exon_counts:
             fidx0e = []
-            fidx1e = [np.where(event_features == 'intron_cov')[0]]
+            fidx1e = [np.where(event_features == 'e2_cov')[0]]
             pos1e = [IN['event_pos'][:, [1, 2]].astype('int')]
     elif event_type in ['alt_3prime', 'alt_5prime']:
-        fidx0i = [np.where(event_features == 'intron1_conf')[0]]
-        fidx1i = [np.where(event_features == 'intron2_conf')[0]]
+        fidx0i = [np.where(event_features == 'e1e3_conf')[0]]
+        fidx1i = [np.where(event_features == 'e2_conf')[0]]
         if options.use_exon_counts:
             fidx0e = []
-            fidx1e = [np.where(event_features == 'exon_diff_cov')[0]]
+            fidx1e = [np.where(event_features == 'e2_cov')[0]]
             pos1e = [np.zeros((IN['event_pos'].shape[0], 2), dtype='int')]
             idx = np.where((IN['event_pos'][:, 4] == IN['event_pos'][:, 6]) & (IN['event_pos'][:, 1] < IN['event_pos'][:, 3]))[0]
             pos1e[0][idx, :] = IN['event_pos'][:, [1, 3]][idx, :].astype('int')
@@ -320,26 +309,26 @@ def quantify_from_counted_events(event_fn, strain_idx1=None, strain_idx2=None, e
             idx = np.where((IN['event_pos'][:, 1] == IN['event_pos'][:, 3]) & (IN['event_pos'][:, 4] > IN['event_pos'][:, 6]))[0]
             pos1e[0][idx, :] = IN['event_pos'][:, [4, 6]][idx, :].astype('int')[:, ::-1]
     elif event_type == 'mult_exon_skip':
-        fidx0i = [np.where(event_features == 'exon_pre_exon_aft_conf')[0]]
-        fidx1i = [np.where(event_features == 'exon_pre_exon_conf')[0], np.where(event_features == 'exon_exon_aft_conf')[0], np.where(event_features == 'sum_inner_exon_conf')[0]] 
-        tmp_idx = np.where(event_features == 'len_inner_exon')[0]
+        fidx0i = [np.where(event_features == 'e1e3_conf')[0]]
+        fidx1i = [np.where(event_features == 'e1e2_conf')[0], np.where(event_features == 'e2e3_conf')[0], np.where(event_features == 'sum_e2_conf')[0]] 
+        tmp_idx = np.where(event_features == 'len_e2')[0]
         if options.use_exon_counts:
             fidx0e = []
-            fidx1e = [np.where(event_features == 'exons_cov')[0]]
+            fidx1e = [np.where(event_features == 'e2_cov')[0]]
             pos1e = [np.c_[np.zeros((IN['event_counts'].shape[2],), dtype='int'), IN['event_counts'][0, tmp_idx, :].astype('int')]]
     elif event_type == 'mutex_exons':
-        fidx0i = [np.where(event_features == 'exon_pre_exon1_conf')[0], np.where(event_features == 'exon1_exon_aft_conf')[0]]
-        fidx1i = [np.where(event_features == 'exon_pre_exon2_conf')[0], np.where(event_features == 'exon2_exon_aft_conf')[0]] 
+        fidx0i = [np.where(event_features == 'e1e2_conf')[0], np.where(event_features == 'e2e4_conf')[0]]
+        fidx1i = [np.where(event_features == 'e1e3_conf')[0], np.where(event_features == 'e3e4_conf')[0]] 
         if options.use_exon_counts:
-            fidx0e = [np.where(event_features == 'exon1_cov')[0]]
-            fidx1e = [np.where(event_features == 'exon2_cov')[0]]
+            fidx0e = [np.where(event_features == 'e2_cov')[0]]
+            fidx1e = [np.where(event_features == 'e3_cov')[0]]
             pos0e = [IN['event_pos'][:, [2, 3]].astype('int')]
             pos1e = [IN['event_pos'][:, [4, 5]].astype('int')]
     else:
         raise Error('Event type %s either not known or not implemented for testing yet' % event_type)
 
     ### init coverage matrix
-    cov = [np.zeros((conf_idx.shape[0], strain_idx1.shape[0] + strain_idx2.shape[0]), dtype='float'), np.zeros((conf_idx.shape[0], strain_idx1.shape[0] + strain_idx2.shape[0]), dtype='float')]
+    cov = [np.zeros((conf_idx.shape[0], sample_idx1.shape[0] + sample_idx2.shape[0]), dtype='float'), np.zeros((conf_idx.shape[0], sample_idx1.shape[0] + sample_idx2.shape[0]), dtype='float')]
 
     for c in pos0e:
         assert(np.all((c[:, 1] - c[:, 0]) >= 0))
@@ -347,100 +336,99 @@ def quantify_from_counted_events(event_fn, strain_idx1=None, strain_idx2=None, e
         assert(np.all((c[:, 1] - c[:, 0]) >= 0))
 
     ### tackle unsorted input
-    s_idx = np.argsort(decodeUTF8(IN['strains'][:]))
-    strain_idx1 = np.sort(s_idx[strain_idx1])
-    strain_idx2 = np.sort(s_idx[strain_idx2])
-    idx1_len = strain_idx1.shape[0]
+    sidx1 = np.argsort(sample_idx1)
+    sidx2 = np.argsort(sample_idx2)
+    ridx1 = np.argsort(sidx1)
+    ridx2 = np.argsort(sidx2)
+    sample_idx1 = sample_idx1[sidx1]
+    sample_idx2 = sample_idx2[sidx2]
+    idx1_len = sample_idx1.shape[0]
 
     ### get counts for exon segments
     if options.use_exon_counts:
         if options.verbose:
             print('Collecting exon segment expression values')
         for f, ff in enumerate(fidx0e):
-            cov[0][:, :idx1_len] += (IN['event_counts'][strain_idx1, ff[0], :][:, conf_idx].T * (pos0e[f][conf_idx, 1].T - pos0e[f][conf_idx, 0])[:, np.newaxis]) / options.readlen
-            cov[0][:, idx1_len:] += (IN['event_counts'][strain_idx2, ff[0], :][:, conf_idx].T * (pos0e[f][conf_idx, 1].T - pos0e[f][conf_idx, 0])[:, np.newaxis]) / options.readlen
+            cov[0][:, :idx1_len] += (IN['event_counts'][sample_idx1, ff[0], :][:, conf_idx].T * (pos0e[f][conf_idx, 1].T - pos0e[f][conf_idx, 0])[:, np.newaxis]) / options.readlen
+            cov[0][:, idx1_len:] += (IN['event_counts'][sample_idx2, ff[0], :][:, conf_idx].T * (pos0e[f][conf_idx, 1].T - pos0e[f][conf_idx, 0])[:, np.newaxis]) / options.readlen
         for f, ff in enumerate(fidx1e):
-            cov[1][:, :idx1_len] += (IN['event_counts'][strain_idx1, ff[0], :][:, conf_idx].T * (pos1e[f][conf_idx, 1].T - pos1e[f][conf_idx, 0])[:, np.newaxis]) / options.readlen
-            cov[1][:, idx1_len:] += (IN['event_counts'][strain_idx2, ff[0], :][:, conf_idx].T * (pos1e[f][conf_idx, 1].T - pos1e[f][conf_idx, 0])[:, np.newaxis]) / options.readlen
+            cov[1][:, :idx1_len] += (IN['event_counts'][sample_idx1, ff[0], :][:, conf_idx].T * (pos1e[f][conf_idx, 1].T - pos1e[f][conf_idx, 0])[:, np.newaxis]) / options.readlen
+            cov[1][:, idx1_len:] += (IN['event_counts'][sample_idx2, ff[0], :][:, conf_idx].T * (pos1e[f][conf_idx, 1].T - pos1e[f][conf_idx, 0])[:, np.newaxis]) / options.readlen
 
     ### get counts for introns
     if options.verbose:
         print('Collecting intron confirmation values')
-
-
-    ### get gene index
-    gene_idx = IN['gene_idx'][:].astype('int')
     cnt1 = []
     cnt2 = []
     for f in fidx0i:
-        cnt1.append(IN['event_counts'][strain_idx1, f[0], :][:, conf_idx].T)
-        cnt2.append(IN['event_counts'][strain_idx2, f[0], :][:, conf_idx].T)
-        #cov[0][:, :idx1_len] += IN['event_counts'][strain_idx1, f[0], :][:, conf_idx].T
-        #cov[0][:, idx1_len:] += IN['event_counts'][strain_idx2, f[0], :][:, conf_idx].T
+        cnt1.append(IN['event_counts'][sample_idx1, f[0], :][:, conf_idx].T)
+        cnt2.append(IN['event_counts'][sample_idx2, f[0], :][:, conf_idx].T)
+        #cov[0][:, :idx1_len] += IN['event_counts'][sample_idx1, f[0], :][:, conf_idx].T
+        #cov[0][:, idx1_len:] += IN['event_counts'][sample_idx2, f[0], :][:, conf_idx].T
     if len(fidx0i) > 0:
         cov[0][:, :idx1_len] += np.array(cnt1).min(axis=0)
         cov[0][:, idx1_len:] += np.array(cnt2).min(axis=0)
     cnt1 = []
     cnt2 = []
     for f in fidx1i:
-        #cov[1][:, :idx1_len] += IN['event_counts'][strain_idx1, f[0], :][:, conf_idx].T
-        #cov[1][:, idx1_len:] += IN['event_counts'][strain_idx2, f[0], :][:, conf_idx].T
-        cnt1.append(IN['event_counts'][strain_idx1, f[0], :][:, conf_idx].T)
-        cnt2.append(IN['event_counts'][strain_idx2, f[0], :][:, conf_idx].T)
+        #cov[1][:, :idx1_len] += IN['event_counts'][sample_idx1, f[0], :][:, conf_idx].T
+        #cov[1][:, idx1_len:] += IN['event_counts'][sample_idx2, f[0], :][:, conf_idx].T
+        cnt1.append(IN['event_counts'][sample_idx1, f[0], :][:, conf_idx].T)
+        cnt2.append(IN['event_counts'][sample_idx2, f[0], :][:, conf_idx].T)
     if len(fidx1i) > 0:
         cov[1][:, :idx1_len] += np.array(cnt1).min(axis=0)
         cov[1][:, idx1_len:] += np.array(cnt2).min(axis=0)
     del cnt1, cnt2
 
-    ### get strain list
-    strains1 = decodeUTF8(IN['strains'][:][strain_idx1])
-    s_idx = np.argsort(strains1)
-    strains1 = strains1[s_idx]
-    cov[0][:, :idx1_len] = cov[0][:, :idx1_len][:, s_idx]
-    cov[1][:, :idx1_len] = cov[1][:, :idx1_len][:, s_idx]
-    strains2 = decodeUTF8(IN['strains'][:][strain_idx2])
-    s_idx = np.argsort(strains2)
-    strains2 = strains2[s_idx]
-    cov[0][:, idx1_len:] = cov[0][:, idx1_len:][:, s_idx]
-    cov[1][:, idx1_len:] = cov[1][:, idx1_len:][:, s_idx]
-    strains = np.r_[strains1, strains2]
+    ### get psi values
+    psi = np.c_[IN['psi'][:, conf_idx][sample_idx1, :].T, IN['psi'][:, conf_idx][sample_idx2, :].T]
 
-    if strains[0].endswith('npz'):
-        strains = np.array([re.sub(r'.[nN][pP][zZ]$', '', x) for x in strains])
+    ### get sample list
+    samples1 = decodeUTF8(IN['samples'][:][sample_idx1])
+    cov[0][:, :idx1_len] = cov[0][:, :idx1_len]
+    cov[1][:, :idx1_len] = cov[1][:, :idx1_len]
+    samples2 = decodeUTF8(IN['samples'][:][sample_idx2])
+    cov[0][:, idx1_len:] = cov[0][:, idx1_len:]
+    cov[1][:, idx1_len:] = cov[1][:, idx1_len:]
+    
+    ## re-establish the original sorting
+    samples = np.r_[samples1[ridx1], samples2[ridx2]]
+    cov[0][:, :idx1_len] = cov[0][:, :idx1_len][:, ridx1]
+    cov[0][:, idx1_len:] = cov[0][:, idx1_len:][:, ridx2]
+    cov[1][:, :idx1_len] = cov[1][:, :idx1_len][:, ridx1]
+    cov[1][:, idx1_len:] = cov[1][:, idx1_len:][:, ridx2]
+
+    if samples[0].endswith('npz'):
+        samples = np.array([re.sub(r'.[nN][pP][zZ]$', '', x) for x in samples])
 
     ### get list of event IDs - we will use these to make event forms unique
     event_ids = None
     if gen_event_ids:
         event_ids = get_event_ids(IN, event_type, conf_idx, options)
 
-    IN.close()
-
+    ### get gene index
+    gene_idx = IN['gene_idx'][:].astype('int')
     ### only keep confident events
     gene_idx = gene_idx[conf_idx]
 
+    IN.close()
+
     ### round to the closest int
     cov[0] = np.floor(cov[0])
     cov[1] = np.floor(cov[1])
 
-    return (cov, gene_idx, event_idx, event_ids, strains)
+    return (cov, psi, gene_idx, event_idx, event_ids, samples)
 
 
-def quantify_from_graph(ev, strain_idx=None, event_type=None, options=None, out_fn=None, fn_merge=None):
-
-    ### set parameters if called by rproc
-    if strain_idx is None:
-        PAR = ev
-        ev = PAR['ev']
-        strain_idx = PAR['strain_idx']
-        if 'out_fn' in PAR:
-            out_fn = PAR['out_fn']
-        event_type = PAR['event_type']
-        options = PAR['options']
+def quantify_from_graph(ev, sample_idx=None, event_type=None, options=None, out_fn=None, fn_merge=None):
 
     if fn_merge is None:
-        fn_merge = get_filename('fn_out_merge_val', options)
+        if options.validate_sg:
+            fn_merge = get_filename('fn_out_merge_val', options)
+        else:
+            fn_merge = get_filename('fn_out_merge', options)
 
-    genes = pickle.load(open(fn_merge_val, 'r'))[0]
+    genes = pickle.load(open(fn_merge, 'r'))[0]
     fn_count = fn_merge.replace('pickle', 'count.hdf5')
 
     ### load count index data from hdf5
@@ -487,14 +475,12 @@ def quantify_from_graph(ev, strain_idx=None, event_type=None, options=None, out_
         assert(gene_ids_edges[genes_f_idx_edges[gr_idx_edges]] == g_idx)
 
         ### laod relevant count data from HDF5
-        segments = IN['segments'][genes_f_idx_segs[gr_idx_segs]:genes_l_idx_segs[gr_idx_segs]+1, strain_idx]
-        seg_pos = IN['seg_pos'][genes_f_idx_segs[gr_idx_segs]:genes_l_idx_segs[gr_idx_segs]+1, strain_idx]
-        edges = IN['edges'][genes_f_idx_edges[gr_idx_edges]:genes_l_idx_edges[gr_idx_edges]+1, strain_idx]
+        segments = IN['segments'][genes_f_idx_segs[gr_idx_segs]:genes_l_idx_segs[gr_idx_segs]+1, sample_idx]
+        seg_pos = IN['seg_pos'][genes_f_idx_segs[gr_idx_segs]:genes_l_idx_segs[gr_idx_segs]+1, sample_idx]
+        edges = IN['edges'][genes_f_idx_edges[gr_idx_edges]:genes_l_idx_edges[gr_idx_edges]+1, sample_idx]
         edge_idx = IN['edge_idx'][genes_f_idx_edges[gr_idx_edges]:genes_l_idx_edges[gr_idx_edges]+1]
 
-        for s_idx in range(len(strain_idx)):
-            #print '%i/%i' % (s_idx, len(strain_idx))
-
+        for s_idx in range(len(sample_idx)):
             if event_type == 'exon_skip':
                 cov = quantify_exon_skip(ev[i], genes[g_idx - offset], segments[:, s_idx].T,  np.c_[edge_idx, edges[:, s_idx]])
             elif event_type in ['alt_3prime', 'alt_5prime']:
