@@ -133,7 +133,7 @@ def verify_intron_retention(event, gene, counts_segments, counts_edges, counts_s
         info[0] = 0
         return (verified, info)
     ### check validity of exon coordinates (start < stop && non-overlapping)
-    elif np.any(event.exons1[:, 1] - event.exons1[:, 0] < 1) or np.any((event.exons2[1] - event.exons2[0]) < 1):
+    elif np.any(event.exons1[:, 1] - event.exons1[:, 0] < 1) or np.any(event.exons2[:, 1] - event.exons2[:, 0] < 1):
         info[0] = 0
         return (verified, info)
 
@@ -173,7 +173,7 @@ def verify_intron_retention(event, gene, counts_segments, counts_edges, counts_s
     if (info[2] > options.intron_retention['min_retention_cov'] and \
         info[5] > options.intron_retention['min_retention_region'] and \
         info[2] >= options.intron_retention['min_retention_rel_cov'] * (info[1] + info[3]) / 2) or \
-       (options.use_anno_support and exon_long in set([(_[0], _[1]) for _ in np.hstack(gene.exons)])):
+       (options.use_anno_support and exon_long in set([(_[0], _[1]) for _ in np.vstack(gene.exons)])):
         verified[0] = 1
 
     ### check intron confirmation as sum of valid intron scores
